@@ -19,10 +19,13 @@ class MobileCommand(object):
     SWITCH_TO_CONTEXT = 'switchToContext'
     TOUCH_ACTION = 'touchAction'
     MULTI_ACTION = 'multiAction'
+    OPEN_NOTIFICATIONS = 'openNotifications'
 
     # Appium Commands
     GET_APP_STRINGS = 'getAppStrings'
     PRESS_KEYCODE = 'pressKeyCode'
+    # TODO: remove when new Appium is out
+    KEY_EVENT = 'keyEvent'
     LONG_PRESS_KEYCODE = 'longPressKeyCode'
     GET_CURRENT_ACTIVITY = 'getCurrentActivity'
     SET_IMMEDIATE_VALUE = 'setImmediateValue'
