@@ -340,6 +340,23 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.HIDE_KEYBOARD, data)
         return self
 
+    # TODO: remove when new Appium is out
+    def keyevent(self, keycode, metastate=None):
+        """Sends a keycode to the device. Android only. Possible keycodes can be
+        found in http://developer.android.com/reference/android/view/KeyEvent.html.
+
+        :Args:
+         - keycode - the keycode to be sent to the device
+         - metastate - meta information about the keycode being sent
+        """
+        data = {
+            'keycode': keycode,
+        }
+        if metastate is not None:
+            data['metastate'] = metastate
+        self.execute(Command.KEY_EVENT, data)
+        return self
+
     def press_keycode(self, keycode, metastate=None):
         """Sends a keycode to the device. Android only. Possible keycodes can be
         found in http://developer.android.com/reference/android/view/KeyEvent.html.
@@ -525,6 +542,12 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.SHAKE)
         return self
 
+    def open_notifications(self):
+        """Open notification shade in Android (API Level 18 and above)
+        """
+        self.execute(Command.OPEN_NOTIFICATIONS, {})
+        return self
+
     def _addCommands(self):
         self.command_executor._commands[Command.CONTEXTS] = \
             ('GET', '/session/$sessionId/contexts')
@@ -538,6 +561,9 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/touch/multi/perform')
         self.command_executor._commands[Command.GET_APP_STRINGS] = \
             ('POST', '/session/$sessionId/appium/app/strings')
+        # TODO: remove when new Appium is out
+        self.command_executor._commands[Command.KEY_EVENT] = \
+            ('POST', '/session/$sessionId/appium/device/keyevent')
         self.command_executor._commands[Command.PRESS_KEYCODE] = \
             ('POST', '/session/$sessionId/appium/device/press_keycode')
         self.command_executor._commands[Command.LONG_PRESS_KEYCODE] = \
@@ -574,6 +600,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/app/reset')
         self.command_executor._commands[Command.HIDE_KEYBOARD] = \
             ('POST', '/session/$sessionId/appium/device/hide_keyboard')
+        self.command_executor._commands[Command.OPEN_NOTIFICATIONS] = \
+            ('POST', '/session/$sessionId/appium/device/open_notifications')
 
 
 # monkeypatched method for WebElement
